Class: Google::Apis::AppengineV1alpha::AppengineService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AppengineV1alpha::AppengineService
- Defined in:
- lib/google/apis/appengine_v1alpha/service.rb
Overview
App Engine Admin API
Provisions and manages developers' App Engine applications.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://appengine.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_app_authorized_certificate(apps_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
-
#create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application.
-
#create_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
-
#create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application.
-
#delete_app_authorized_certificate(apps_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
-
#delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping.
-
#delete_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
-
#delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping.
-
#get_app_authorized_certificate(apps_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
-
#get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
-
#get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
-
#get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
-
#get_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
-
#get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
-
#get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ AppengineService
constructor
A new instance of AppengineService.
-
#list_app_authorized_certificates(apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
-
#list_app_authorized_domains(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
-
#list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
-
#list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: Global locations: If name is empty, the method lists the public locations available to all projects.
-
#list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_application_authorized_certificates(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
-
#list_project_location_application_authorized_domains(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
-
#list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
-
#list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: Global locations: If name is empty, the method lists the public locations available to all projects.
-
#patch_app_authorized_certificate(apps_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate.
-
#patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping.
-
#patch_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate.
-
#patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping.
Constructor Details
#initialize ⇒ AppengineService
Returns a new instance of AppengineService.
47 48 49 50 51 52 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-appengine_v1alpha', client_version: Google::Apis::AppengineV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_app_authorized_certificate(apps_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 76 def (apps_id, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/apps/{appsId}/authorizedCertificates', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application. A user must be authorized to administer a domain in order to map it to an application. For a list of available authorized domains, see AuthorizedDomains.ListAuthorizedDomains.
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 312 def create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/apps/{appsId}/domainMappings', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['overrideStrategy'] = override_strategy unless override_strategy.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
769 770 771 772 773 774 775 776 777 778 779 780 781 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 769 def (projects_id, locations_id, applications_id, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application. A user must be authorized to administer a domain in order to map it to an application. For a list of available authorized domains, see AuthorizedDomains.ListAuthorizedDomains.
1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1041 def create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['overrideStrategy'] = override_strategy unless override_strategy.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_app_authorized_certificate(apps_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 111 def (apps_id, , fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Empty::Representation command.response_class = Google::Apis::AppengineV1alpha::Empty command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping. A user must be authorized to administer the associated domain in order to delete a DomainMapping resource.
350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 350 def delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
810 811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 810 def (projects_id, locations_id, applications_id, , fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Empty::Representation command.response_class = Google::Apis::AppengineV1alpha::Empty command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping. A user must be authorized to administer the associated domain in order to delete a DomainMapping resource.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1085 def delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_authorized_certificate(apps_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 147 def (apps_id, , view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
384 385 386 387 388 389 390 391 392 393 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 384 def get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.response_class = Google::Apis::AppengineV1alpha::DomainMapping command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
504 505 506 507 508 509 510 511 512 513 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 504 def get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/locations/{locationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Location::Representation command.response_class = Google::Apis::AppengineV1alpha::Location command.params['appsId'] = apps_id unless apps_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
594 595 596 597 598 599 600 601 602 603 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 594 def get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/operations/{operationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['operationsId'] = operations_id unless operations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
676 677 678 679 680 681 682 683 684 685 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 676 def get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Location::Representation command.response_class = Google::Apis::AppengineV1alpha::Location command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
852 853 854 855 856 857 858 859 860 861 862 863 864 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 852 def (projects_id, locations_id, applications_id, , view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1125 def get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.response_class = Google::Apis::AppengineV1alpha::DomainMapping command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1262 def get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['operationsId'] = operations_id unless operations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_authorized_certificates(apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 186 def (apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedCertificates', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_authorized_domains(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 268 def (apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedDomains', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 420 def list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/domainMappings', ) command.response_representation = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: Global locations: If name is empty, the
method lists the public locations available to all projects. Project-specific
locations: If name follows the format projects/project, the method lists
locations visible to that specific project. This includes public, private, or
other project-specific locations enabled for the project.For gRPC and client
library implementations, the resource name is passed as the name field. For
direct service calls, the resource name is incorporated into the request path
based on the specific service implementation and version.
557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 557 def list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/locations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListLocationsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 640 def list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/operations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListOperationsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_authorized_certificates(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
897 898 899 900 901 902 903 904 905 906 907 908 909 910 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 897 def (projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_authorized_domains(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 991 def (projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedDomains', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1167 def list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings', ) command.response_representation = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1311 def list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/operations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListOperationsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: Global locations: If name is empty, the
method lists the public locations available to all projects. Project-specific
locations: If name follows the format projects/project, the method lists
locations visible to that specific project. This includes public, private, or
other project-specific locations enabled for the project.For gRPC and client
library implementations, the resource name is passed as the name field. For
direct service calls, the resource name is incorporated into the request path
based on the specific service implementation and version.
729 730 731 732 733 734 735 736 737 738 739 740 741 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 729 def list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListLocationsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_app_authorized_certificate(apps_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate. To renew a certificate and maintain its existing domain mappings, update certificate_data with a new certificate. The new certificate must be applicable to the same domains as the original certificate. The certificate display_name may also be updated.
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 229 def (apps_id, , = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping. To map an SSL certificate to a domain mapping, update certificate_id to point to an AuthorizedCertificate resource. A user must be authorized to administer the associated domain in order to update a DomainMapping resource.
467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 467 def patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate. To renew a certificate and maintain its existing domain mappings, update certificate_data with a new certificate. The new certificate must be applicable to the same domains as the original certificate. The certificate display_name may also be updated.
946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 946 def (projects_id, locations_id, applications_id, , = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping. To map an SSL certificate to a domain mapping, update certificate_id to point to an AuthorizedCertificate resource. A user must be authorized to administer the associated domain in order to update a DomainMapping resource.
1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1220 def patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |