Class: Google::Apis::AppengineV1alpha::AuthorizedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

An SSL certificate that a user has been authorized to administer. A user is authorized to administer any certificate that applies to one of their authorized domains.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthorizedCertificate

Returns a new instance of AuthorizedCertificate.



93
94
95
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 93

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_raw_dataGoogle::Apis::AppengineV1alpha::CertificateRawData

An SSL certificate obtained from a certificate authority. Corresponds to the JSON property certificateRawData



34
35
36
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 34

def certificate_raw_data
  @certificate_raw_data
end

#display_nameString

The user-specified display name of the certificate. This is not guaranteed to be unique. Example: My Certificate. Corresponds to the JSON property displayName

Returns:

  • (String)


40
41
42
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 40

def display_name
  @display_name
end

#domain_mappings_countFixnum

Aggregate count of the domain mappings with this certificate mapped. This count includes domain mappings on applications for which the user does not have VIEWER permissions.Only returned by GET or LIST requests when specifically requested by the view=FULL_CERTIFICATE option.@OutputOnly Corresponds to the JSON property domainMappingsCount

Returns:

  • (Fixnum)


48
49
50
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 48

def domain_mappings_count
  @domain_mappings_count
end

#domain_namesArray<String>

Output only. Topmost applicable domains of this certificate. This certificate applies to these domains and their subdomains. Example: example.com.@ OutputOnly Corresponds to the JSON property domainNames

Returns:

  • (Array<String>)


55
56
57
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 55

def domain_names
  @domain_names
end

#expire_timeString

The time when this certificate expires. To update the renewal time on this certificate, upload an SSL certificate with a different expiration time using AuthorizedCertificates.UpdateAuthorizedCertificate.@OutputOnly Corresponds to the JSON property expireTime

Returns:

  • (String)


62
63
64
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 62

def expire_time
  @expire_time
end

#idString

Output only. Relative name of the certificate. This is a unique value autogenerated on AuthorizedCertificate resource creation. Example: 12345.@ OutputOnly Corresponds to the JSON property id

Returns:

  • (String)


69
70
71
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 69

def id
  @id
end

#managed_certificateGoogle::Apis::AppengineV1alpha::ManagedCertificate

A certificate managed by App Engine. Corresponds to the JSON property managedCertificate



74
75
76
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 74

def managed_certificate
  @managed_certificate
end

#nameString

Output only. Full path to the AuthorizedCertificate resource in the API. Example: apps/myapp/authorizedCertificates/12345.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


80
81
82
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 80

def name
  @name
end

#visible_domain_mappingsArray<String>

Output only. The full paths to user visible Domain Mapping resources that have this certificate mapped. Example: apps/myapp/domainMappings/example.com.This may not represent the full list of mapped domain mappings if the user does not have VIEWER permissions on all of the applications that have this certificate mapped. See domain_mappings_count for a complete count.Only returned by GET or LIST requests when specifically requested by the view=FULL_CERTIFICATE option.@ OutputOnly Corresponds to the JSON property visibleDomainMappings

Returns:

  • (Array<String>)


91
92
93
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 91

def visible_domain_mappings
  @visible_domain_mappings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



98
99
100
101
102
103
104
105
106
107
108
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 98

def update!(**args)
  @certificate_raw_data = args[:certificate_raw_data] if args.key?(:certificate_raw_data)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domain_mappings_count = args[:domain_mappings_count] if args.key?(:domain_mappings_count)
  @domain_names = args[:domain_names] if args.key?(:domain_names)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @id = args[:id] if args.key?(:id)
  @managed_certificate = args[:managed_certificate] if args.key?(:managed_certificate)
  @name = args[:name] if args.key?(:name)
  @visible_domain_mappings = args[:visible_domain_mappings] if args.key?(:visible_domain_mappings)
end