Class: Google::Apis::AppengineV1alpha::ContainerState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH. This data is not persisted by CCFE, but is instead derived from CCFE's internal representation of the container state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContainerState

Returns a new instance of ContainerState.



201
202
203
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_reasonsGoogle::Apis::AppengineV1alpha::Reasons

Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller) Corresponds to the JSON property currentReasons



184
185
186
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 184

def current_reasons
  @current_reasons
end

#previous_reasonsGoogle::Apis::AppengineV1alpha::Reasons

Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller) Corresponds to the JSON property previousReasons



193
194
195
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 193

def previous_reasons
  @previous_reasons
end

#stateString

The current state of the container. This state is the culmination of all of the opinions from external systems that CCFE knows about of the container. Corresponds to the JSON property state

Returns:

  • (String)


199
200
201
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 199

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



206
207
208
209
210
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 206

def update!(**args)
  @current_reasons = args[:current_reasons] if args.key?(:current_reasons)
  @previous_reasons = args[:previous_reasons] if args.key?(:previous_reasons)
  @state = args[:state] if args.key?(:state)
end