Class: Google::Apis::AppengineV1alpha::DomainMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

A domain serving an App Engine application.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DomainMapping

Returns a new instance of DomainMapping.



303
304
305
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Relative name of the domain serving the application. Example: example.com. Corresponds to the JSON property id

Returns:

  • (String)


283
284
285
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 283

def id
  @id
end

#nameString

Output only. Full path to the DomainMapping resource in the API. Example: apps/ myapp/domainMapping/example.com.@OutputOnly Corresponds to the JSON property name

Returns:

  • (String)


289
290
291
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 289

def name
  @name
end

#resource_recordsArray<Google::Apis::AppengineV1alpha::ResourceRecord>

Output only. The resource records required to configure this domain mapping. These records must be added to the domain's DNS configuration in order to serve the application via this domain mapping.@OutputOnly Corresponds to the JSON property resourceRecords



296
297
298
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 296

def resource_records
  @resource_records
end

#ssl_settingsGoogle::Apis::AppengineV1alpha::SslSettings

SSL configuration for a DomainMapping resource. Corresponds to the JSON property sslSettings



301
302
303
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 301

def ssl_settings
  @ssl_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



308
309
310
311
312
313
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 308

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @resource_records = args[:resource_records] if args.key?(:resource_records)
  @ssl_settings = args[:ssl_settings] if args.key?(:ssl_settings)
end