Class: Google::Apis::AppengineV1alpha::ManagedCertificate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

A certificate managed by App Engine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedCertificate

Returns a new instance of ManagedCertificate.



627
628
629
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 627

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#last_renewal_timeString

Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly Corresponds to the JSON property lastRenewalTime

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 619

def last_renewal_time
  @last_renewal_time
end

#statusString

Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly Corresponds to the JSON property status

Returns:

  • (String)


625
626
627
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 625

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



632
633
634
635
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 632

def update!(**args)
  @last_renewal_time = args[:last_renewal_time] if args.key?(:last_renewal_time)
  @status = args[:status] if args.key?(:status)
end