Class: Google::Apis::AppengineV1alpha::ResourceEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

The request that is passed to CLH during per-resource events. The request will be sent with update semantics in all cases except for data governance purge events. These events will be sent with delete semantics and the CLH is expected to delete the resource receiving this event.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceEvent

Returns a new instance of ResourceEvent.



1097
1098
1099
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1097

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#event_idString

The unique ID for this per-resource event. CLHs can use this value to dedup repeated calls. required Corresponds to the JSON property eventId

Returns:

  • (String)


1082
1083
1084
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1082

def event_id
  @event_id
end

#nameString

The name of the resource for which this event is. required Corresponds to the JSON property name

Returns:

  • (String)


1087
1088
1089
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1087

def name
  @name
end

#stateGoogle::Apis::AppengineV1alpha::ContainerState

ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH. This data is not persisted by CCFE, but is instead derived from CCFE's internal representation of the container state. Corresponds to the JSON property state



1095
1096
1097
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1095

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1102
1103
1104
1105
1106
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1102

def update!(**args)
  @event_id = args[:event_id] if args.key?(:event_id)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end