Class: Google::Apis::AppengineV1alpha::ResourceRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb

Overview

A DNS resource record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceRecord

Returns a new instance of ResourceRecord.



1120
1121
1122
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Relative name of the object affected by this record. Only applicable for CNAME records. Example: 'www'. Corresponds to the JSON property name

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1107

def name
  @name
end

#rrdataString

Data for this record. Values vary by record type, as defined in RFC 1035 ( section 5) and RFC 1034 (section 3.6.1). Corresponds to the JSON property rrdata

Returns:

  • (String)


1113
1114
1115
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1113

def rrdata
  @rrdata
end

#typeString

Resource record type. Example: AAAA. Corresponds to the JSON property type

Returns:

  • (String)


1118
1119
1120
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1118

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1125
1126
1127
1128
1129
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1125

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @rrdata = args[:rrdata] if args.key?(:rrdata)
  @type = args[:type] if args.key?(:type)
end