Class: Google::Apis::AppengineV1alpha::AppengineService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::AppengineV1alpha::AppengineService
- Defined in:
- lib/google/apis/appengine_v1alpha/service.rb
Overview
App Engine Admin API
Provisions and manages developers' App Engine applications.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://appengine.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_app_authorized_certificate(apps_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
-
#create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application.
-
#create_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
-
#create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application.
-
#delete_app_authorized_certificate(apps_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
-
#delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping.
-
#delete_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
-
#delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping.
-
#get_app_authorized_certificate(apps_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
-
#get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
-
#get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
-
#get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation.
-
#get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
-
#get_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
-
#get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
-
#get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ AppengineService
constructor
A new instance of AppengineService.
-
#list_app_authorized_certificates(apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
-
#list_app_authorized_domains(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
-
#list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
-
#list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_application_authorized_certificates(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
-
#list_project_location_application_authorized_domains(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
-
#list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
-
#list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_app_authorized_certificate(apps_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate.
-
#patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping.
-
#patch_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate.
-
#patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping.
Constructor Details
#initialize ⇒ AppengineService
Returns a new instance of AppengineService.
47 48 49 50 51 52 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-appengine_v1alpha', client_version: Google::Apis::AppengineV1alpha::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_app_authorized_certificate(apps_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 76 def (apps_id, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/apps/{appsId}/authorizedCertificates', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application. A user must be authorized to administer a domain in order to map it to an application. For a list of available authorized domains, see AuthorizedDomains.ListAuthorizedDomains.
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 312 def create_app_domain_mapping(apps_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/apps/{appsId}/domainMappings', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['overrideStrategy'] = override_strategy unless override_strategy.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificate_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Uploads the specified SSL certificate.
751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 751 def (projects_id, locations_id, applications_id, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Maps a domain to an application. A user must be authorized to administer a domain in order to map it to an application. For a list of available authorized domains, see AuthorizedDomains.ListAuthorizedDomains.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1023 def create_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mapping_object = nil, no_managed_certificate: nil, override_strategy: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['overrideStrategy'] = override_strategy unless override_strategy.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_app_authorized_certificate(apps_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 111 def (apps_id, , fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Empty::Representation command.response_class = Google::Apis::AppengineV1alpha::Empty command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping. A user must be authorized to administer the associated domain in order to delete a DomainMapping resource.
350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 350 def delete_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Empty
Deletes the specified SSL certificate.
792 793 794 795 796 797 798 799 800 801 802 803 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 792 def (projects_id, locations_id, applications_id, , fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Empty::Representation command.response_class = Google::Apis::AppengineV1alpha::Empty command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Deletes the specified domain mapping. A user must be authorized to administer the associated domain in order to delete a DomainMapping resource.
1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1067 def delete_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_authorized_certificate(apps_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 147 def (apps_id, , view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
384 385 386 387 388 389 390 391 392 393 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 384 def get_app_domain_mapping(apps_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.response_class = Google::Apis::AppengineV1alpha::DomainMapping command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
504 505 506 507 508 509 510 511 512 513 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 504 def get_app_location(apps_id, locations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/locations/{locationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Location::Representation command.response_class = Google::Apis::AppengineV1alpha::Location command.params['appsId'] = apps_id unless apps_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
585 586 587 588 589 590 591 592 593 594 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 585 def get_app_operation(apps_id, operations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/operations/{operationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['operationsId'] = operations_id unless operations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Location
Gets information about a location.
667 668 669 670 671 672 673 674 675 676 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 667 def get_project_location(projects_id, locations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Location::Representation command.response_class = Google::Apis::AppengineV1alpha::Location command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Gets the specified SSL certificate.
834 835 836 837 838 839 840 841 842 843 844 845 846 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 834 def (projects_id, locations_id, applications_id, , view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::DomainMapping
Gets the specified domain mapping.
1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1107 def get_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.response_class = Google::Apis::AppengineV1alpha::DomainMapping command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1244 def get_project_location_operation(projects_id, locations_id, operations_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}', ) command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['operationsId'] = operations_id unless operations_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_authorized_certificates(apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 186 def (apps_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedCertificates', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_authorized_domains(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 268 def (apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/authorizedDomains', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 420 def list_app_domain_mappings(apps_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/domainMappings', ) command.response_representation = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 548 def list_app_locations(apps_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/locations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListLocationsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
631 632 633 634 635 636 637 638 639 640 641 642 643 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 631 def list_app_operations(apps_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/apps/{appsId}/operations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListOperationsResponse command.params['appsId'] = apps_id unless apps_id.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_authorized_certificates(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse
Lists all SSL certificates the user is authorized to administer.
879 880 881 882 883 884 885 886 887 888 889 890 891 892 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 879 def (projects_id, locations_id, applications_id, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedCertificatesResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_authorized_domains(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse
Lists all domains the user is authorized to administer.
973 974 975 976 977 978 979 980 981 982 983 984 985 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 973 def (projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedDomains', ) command.response_representation = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListAuthorizedDomainsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListDomainMappingsResponse
Lists the domain mappings on an application.
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1149 def list_project_location_application_domain_mappings(projects_id, locations_id, applications_id, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings', ) command.response_representation = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListDomainMappingsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
1293 1294 1295 1296 1297 1298 1299 1300 1301 1302 1303 1304 1305 1306 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1293 def list_project_location_operations(projects_id, locations_id, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations/{locationsId}/operations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListOperationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListOperationsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::ListLocationsResponse
Lists information about the supported locations for this service.
711 712 713 714 715 716 717 718 719 720 721 722 723 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 711 def list_project_locations(projects_id, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1alpha/projects/{projectsId}/locations', ) command.response_representation = Google::Apis::AppengineV1alpha::ListLocationsResponse::Representation command.response_class = Google::Apis::AppengineV1alpha::ListLocationsResponse command.params['projectsId'] = projects_id unless projects_id.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_app_authorized_certificate(apps_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate. To renew a certificate and maintain its existing domain mappings, update certificate_data with a new certificate. The new certificate must be applicable to the same domains as the original certificate. The certificate display_name may also be updated.
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 229 def (apps_id, , = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['appsId'] = apps_id unless apps_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping. To map an SSL certificate to a domain mapping, update certificate_id to point to an AuthorizedCertificate resource. A user must be authorized to administer the associated domain in order to update a DomainMapping resource.
467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 467 def patch_app_domain_mapping(apps_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/apps/{appsId}/domainMappings/{domainMappingsId}', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['appsId'] = apps_id unless apps_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_authorized_certificate(projects_id, locations_id, applications_id, authorized_certificates_id, authorized_certificate_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::AuthorizedCertificate
Updates the specified SSL certificate. To renew a certificate and maintain its existing domain mappings, update certificate_data with a new certificate. The new certificate must be applicable to the same domains as the original certificate. The certificate display_name may also be updated.
928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 928 def (projects_id, locations_id, applications_id, , = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/authorizedCertificates/{authorizedCertificatesId}', ) command.request_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.request_object = command.response_representation = Google::Apis::AppengineV1alpha::AuthorizedCertificate::Representation command.response_class = Google::Apis::AppengineV1alpha::AuthorizedCertificate command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['authorizedCertificatesId'] = unless .nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::AppengineV1alpha::Operation
Updates the specified domain mapping. To map an SSL certificate to a domain mapping, update certificate_id to point to an AuthorizedCertificate resource. A user must be authorized to administer the associated domain in order to update a DomainMapping resource.
1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/google/apis/appengine_v1alpha/service.rb', line 1202 def patch_project_location_application_domain_mapping(projects_id, locations_id, applications_id, domain_mappings_id, domain_mapping_object = nil, no_managed_certificate: nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1alpha/projects/{projectsId}/locations/{locationsId}/applications/{applicationsId}/domainMappings/{domainMappingsId}', ) command.request_representation = Google::Apis::AppengineV1alpha::DomainMapping::Representation command.request_object = domain_mapping_object command.response_representation = Google::Apis::AppengineV1alpha::Operation::Representation command.response_class = Google::Apis::AppengineV1alpha::Operation command.params['projectsId'] = projects_id unless projects_id.nil? command.params['locationsId'] = locations_id unless locations_id.nil? command.params['applicationsId'] = applications_id unless applications_id.nil? command.params['domainMappingsId'] = domain_mappings_id unless domain_mappings_id.nil? command.query['noManagedCertificate'] = no_managed_certificate unless no_managed_certificate.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |