Class: Google::Apis::AppengineV1alpha::ProjectEvent
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1alpha::ProjectEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb
Overview
The request sent to CLHs during project events.
Instance Attribute Summary collapse
-
#event_id ⇒ String
The unique ID for this project event.
-
#phase ⇒ String
Phase indicates when in the container event propagation this event is being communicated.
-
#project_metadata ⇒ Google::Apis::AppengineV1alpha::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant projects (tenant, consumer, producer).
-
#state ⇒ Google::Apis::AppengineV1alpha::ContainerState
ContainerState contains the externally-visible container state that is used to communicate the state and reasoning for that state to the CLH.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectEvent
constructor
A new instance of ProjectEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectEvent
Returns a new instance of ProjectEvent.
926 927 928 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 926 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event_id ⇒ String
The unique ID for this project event. CLHs can use this value to dedup
repeated calls. required
Corresponds to the JSON property eventId
903 904 905 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 903 def event_id @event_id end |
#phase ⇒ String
Phase indicates when in the container event propagation this event is being
communicated. Events are sent before and after the per-resource events are
propagated. required
Corresponds to the JSON property phase
910 911 912 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 910 def phase @phase end |
#project_metadata ⇒ Google::Apis::AppengineV1alpha::ProjectsMetadata
ProjectsMetadata is the metadata CCFE stores about the all the relevant
projects (tenant, consumer, producer).
Corresponds to the JSON property projectMetadata
916 917 918 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 916 def @project_metadata end |
#state ⇒ Google::Apis::AppengineV1alpha::ContainerState
ContainerState contains the externally-visible container state that is used to
communicate the state and reasoning for that state to the CLH. This data is
not persisted by CCFE, but is instead derived from CCFE's internal
representation of the container state.
Corresponds to the JSON property state
924 925 926 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 924 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
931 932 933 934 935 936 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 931 def update!(**args) @event_id = args[:event_id] if args.key?(:event_id) @phase = args[:phase] if args.key?(:phase) @project_metadata = args[:project_metadata] if args.key?(:project_metadata) @state = args[:state] if args.key?(:state) end |