Class: Google::Apis::AppengineV1alpha::Reasons
- Inherits:
-
Object
- Object
- Google::Apis::AppengineV1alpha::Reasons
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/appengine_v1alpha/classes.rb,
lib/google/apis/appengine_v1alpha/representations.rb,
lib/google/apis/appengine_v1alpha/representations.rb
Overview
Containers transition between and within states based on reasons sent from various systems. CCFE will provide the CLH with reasons for the current state per system.The current systems that CCFE supports are: Service Management ( Inception) Data Governance (Wipeout) Abuse (Ares) Billing (Internal Cloud Billing API) Service Activation (Service Controller)
Instance Attribute Summary collapse
-
#abuse ⇒ String
Corresponds to the JSON property
abuse. -
#billing ⇒ String
Corresponds to the JSON property
billing. -
#data_governance ⇒ String
Corresponds to the JSON property
dataGovernance. -
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
-
#service_management ⇒ String
Corresponds to the JSON property
serviceManagement.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reasons
constructor
A new instance of Reasons.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reasons
Returns a new instance of Reasons.
1047 1048 1049 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ String
Corresponds to the JSON property abuse
1023 1024 1025 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1023 def abuse @abuse end |
#billing ⇒ String
Corresponds to the JSON property billing
1028 1029 1030 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1028 def billing @billing end |
#data_governance ⇒ String
Corresponds to the JSON property dataGovernance
1033 1034 1035 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1033 def data_governance @data_governance end |
#service_activation ⇒ String
Consumer Container denotes if the service is active within a project or not.
This information could be used to clean up resources in case service in
DISABLED_FULL i.e. Service is inactive > 30 days.
Corresponds to the JSON property serviceActivation
1040 1041 1042 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1040 def service_activation @service_activation end |
#service_management ⇒ String
Corresponds to the JSON property serviceManagement
1045 1046 1047 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1045 def service_management @service_management end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/google/apis/appengine_v1alpha/classes.rb', line 1052 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @billing = args[:billing] if args.key?(:billing) @data_governance = args[:data_governance] if args.key?(:data_governance) @service_activation = args[:service_activation] if args.key?(:service_activation) @service_management = args[:service_management] if args.key?(:service_management) end |